---
title: <span class="badge builder"></span> QueryEditorFunctionExpression
---
# <span class="badge builder"></span> QueryEditorFunctionExpression

## Constructor

```python
QueryEditorFunctionExpression()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> bigquery.QueryEditorFunctionExpression
```

### <span class="badge object-method"></span> name

```python
def name(name: str) -> typing.Self
```

### <span class="badge object-method"></span> parameters

```python
def parameters(parameters: list[cogbuilder.Builder[bigquery.QueryEditorFunctionParameterExpression]]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [QueryEditorFunctionExpression](./object-QueryEditorFunctionExpression.md)
